# -*- coding: utf-8 -*-
"""
Created on Tue Sep  1 15:23:50 2020

@author: rdvan
"""
import sympy as sym


def solve_and_print(eq, var):
    """
    Uses Sympy to solve a set of equations symbolically
    
    Parameters
    ----------
    eq : List ([]) of symbolic defined equations
    var : List ([]) of symbolic variables

    Returns
    ----------
    symoblic solution and prints pretty form of solution
    """
    sol = sym.solve(eq, var)
    
    for i in range(len(sol)):
       print('Equilibrium point ' + str(i) + ': '+ sym.pretty(sol[i]))
       
    return sol

def calc_jacobian(eq, var):
    """
    Given set of equations and list of variables, calculate and print Jacobian 
    matrix

    Parameters
    ----------
    eq : List ([]) of symbolic defined equations
    var : List ([]) of symbolic variables

    Returns
    -------
    Symbolic Jacobian

    """
    A = sym.Matrix(eq)
    x = sym.Matrix(var)
    Jac = A.jacobian(x)
    return Jac

def eval_jacobian(jac, var, val):
    """
    Evaluate the jacobian by replacing variabels with a certain value

    Parameters
    ----------
    jac : Symbolic jacobian
    var : list ([]): Symbolic variable that should be replaced
    val : List ([]): Values, both symbolic as numerical, with what the symbolic
                     variable should be replaced

    Returns
    ----------
    Symbolic Jacobian

    """
    zipped = zip(var,val)
    new_jac = jac.subs(tuple(zipped))
    
    return new_jac

def calc_secular_equation(jac):
    """
    Parameters
    ----------
    jac : Symbolic jacobian

    Returns
    -------
    Symbolic secular equation

    """
    y = sym.symbols('y')
    return (jac-y*sym.eye(jac.shape[0])).det()

def print_eigenval_latex(eigenvalues):
    """
    Parameters
    ----------
    eigenvalues : Symbolic eigenvalue

    Returns
    -------
    None. --> prints latex version

    """
    for key,value in eigenvalues.items():
        print(sym.latex(key))